==> haskell-test-framework-0.8.2.0-704.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework
version:              0.8.2.0
visibility:           public
id:                   test-framework-0.8.2.0-5uvP7zRH3Y54oipi1F1CKa
key:                  test-framework-0.8.2.0-5uvP7zRH3Y54oipi1F1CKa
license:              BSD-3-Clause
maintainer:           Libraries List <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  4406eac646e0510ebdcbde9167fa51d5
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.2.8/site-local/test-framework-0.8.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.0-5uvP7zRH3Y54oipi1F1CKa
depends:
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    ansi-wl-pprint-0.6.9-9ctTtDT9IMdHR9rtwZQvOW base-4.16.4.0
    containers-0.6.5.1 hostname-1.0-7J3r6zYiFrqIUVPbgMuhYv
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq time-1.11.1.1
    xml-1.3.14-6RhFPlxQprr192No4Dq3gf

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.2.2-29.8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework
version:              0.8.2.2
visibility:           public
id:                   test-framework-0.8.2.2-CTx0LQHgi9MHshLk1aycwt
key:                  test-framework-0.8.2.2-CTx0LQHgi9MHshLk1aycwt
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  6abbe7df1ccd100e04b2a128e3ace69d
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-0.8.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.2-CTx0LQHgi9MHshLk1aycwt
depends:
    ansi-terminal-1.0.2-CHKNXEXhuZ3EvZtvAUncPO
    ansi-wl-pprint-0.6.9-5BK1jGC8Azm6PTKOUvlx5t base-4.17.2.1
    containers-0.6.7 hostname-1.0-LeTF2MpavibDHBTJAkCOwY
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9 time-1.12.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
